# Py Encry <!-- omit in toc -->

[![Python](https://img.shields.io/badge/support-9101FF?logo=python&logoColor=FFDF58&labelColor=3D7AAB&label=Python%203.12)](https://www.python.org/downloads/release/python-3120/)&nbsp;&nbsp; [![Build Status](https://github.com/Py-Encry/py-encry/workflows/Tests/badge.svg)](https://github.com/Py-Encry/py-encry/actions/workflows/tests.yml)

Nti Johanneberg gymnasiearbete 2023/2024

## Description <!-- omit in toc -->

Py Encry is a library for encrypting and decrypting information in pictures.
The library offers a variety of different encryption methods, and also allows to combine them.
There is an API mode, which allows to use the library in other projects, and a CLI mode, which allows to use the library from the command line.
Additionally, the tool is accesable through our website.

## Table of Contents <!-- omit in toc -->

- [Installation](#installation)
- [Usage](#usage)
- [Contributing](#contributing)
  - [Setup](#setup)
  - [Run tests](#run-tests)
- [License](#license)

## Installation

To install Py Encry, you need to have Python 3.11 or higher installed on your computer.
The library is available on [PyPI](https://pypi.org/project/py-encry/), so you can install it using pip.

```bash
python -m pip install py-encry
```

## Usage

TBD

## Contributing

If you want to contribute to Py Encry, you can do so by forking the repository and creating a pull request.
To build the project, you need to have Python 3.11 or higher installed on your computer and install the required packages.

### Setup

Use the package manager [pip](https://pip.pypa.io/en/stable/) to install the required packages.

```bash
python -m pip install -r requirements.txt
```

### Run tests

```bash
python -m pytest
```

## License

[MIT](./LICENSE)
